@@ -112,8 +112,8 @@ Returns the process associated with the connection."
   (let ((process-buffer
 	 (get-buffer-create (format "trace of POP session to %s" mailhost)))
 	(process)
-	(coding-system-for-read 'no-conversion)   ;; because FSF Emacs 20
-	(coding-system-for-write 'no-conversion)  ;; is st00pid
+	(coding-system-for-read 'binary)   ;; because FSF Emacs 20 and
+	(coding-system-for-write 'binary)  ;; XEmacs 20/1 are st00pid 
     )
     (save-excursion
       (set-buffer process-buffer)
